"""Complete field name mappings for PFF event data."""

EVENTS_FIELD_MAP = {
    # Game event fields
    'game_event_bodyType': 'game_event_body_type',
    'game_event_comment': 'game_event_comment',
    'game_event_duration': 'game_event_duration',
    'game_event_earlyDistribution': 'game_event_early_distribution',
    'game_event_endPointX': 'game_event_end_point_x',
    'game_event_endPointY': 'game_event_end_point_y',
    'game_event_endTime': 'game_event_end_time',
    'game_event_facingType': 'game_event_facing_type',
    'game_event_formattedGameClock': 'game_event_formatted_game_clock',
    'game_event_gameClock': 'game_event_game_clock',
    'game_event_gameEventType': 'game_event_type',
    'game_event_game_id': 'game_event_game_id',
    'game_event_id': 'game_event_id',
    'game_event_initialTouchType': 'game_event_initial_touch_type',
    'game_event_otherPlayer': 'game_event_other_player',
    'game_event_outType': 'game_event_out_type',
    'game_event_period': 'game_event_period',
    'game_event_player': 'game_event_player',
    'game_event_playerOff': 'game_event_player_off',
    'game_event_playerOffType': 'game_event_player_off_type',
    'game_event_playerOn': 'game_event_player_on',
    'game_event_player_id': 'game_event_player_id',
    'game_event_pressurePlayer': 'game_event_pressure_player',
    'game_event_pressurePlayer_id': 'game_event_pressure_player_id',
    'game_event_pressureType': 'game_event_pressure_type',
    'game_event_setpieceType': 'game_event_setpiece_type',
    'game_event_startPointX': 'game_event_start_point_x',
    'game_event_startPointY': 'game_event_start_point_y',
    'game_event_startTime': 'game_event_start_time',
    'game_event_team': 'game_event_team',
    'game_event_team_id': 'game_event_team_id',
    'game_event_team_name': 'game_event_team_name',
    'game_event_team_shortName': 'game_event_team_short_name',
    'game_event_touches': 'game_event_touches',
    'game_event_touchesInBox': 'game_event_touches_in_box',
    'game_event_videoUrl': 'game_event_video_url',
    # Possession event fields
    'possession_event_duration': 'possession_event_duration',
    'possession_event_endTime': 'possession_event_end_time',
    'possession_event_formattedGameClock': 'possession_event_formatted_game_clock',
    'possession_event_gameClock': 'possession_event_game_clock',
    'possession_event_gameEvent_id': 'possession_event_game_event_id',
    'possession_event_id': 'possession_event_id',
    'possession_event_insertedAt': 'possession_event_inserted_at',
    'possession_event_possessionEventType': 'possession_event_type',
    'possession_event_startTime': 'possession_event_start_time',
    'possession_event_updatedAt': 'possession_event_updated_at',
    'possession_event_videoUrl': 'possession_event_video_url',
    # Ball carry fields
    'ballCarry_additionalChallenger1': 'ball_carry_additional_challenger_1',
    'ballCarry_additionalChallenger2': 'ball_carry_additional_challenger_2',
    'ballCarry_additionalChallenger3': 'ball_carry_additional_challenger_3',
    'ballCarry_badParry': 'ball_carry_bad_parry',
    'ballCarry_ballCarrierPlayer_id': 'ball_carry_carrier_player_id',
    'ballCarry_ballCarryEndPointX': 'ball_carry_end_point_x',
    'ballCarry_ballCarryEndPointY': 'ball_carry_end_point_y',
    'ballCarry_ballCarryOutcome': 'ball_carry_outcome',
    'ballCarry_ballCarryStartPointX': 'ball_carry_start_point_x',
    'ballCarry_ballCarryStartPointY': 'ball_carry_start_point_y',
    'ballCarry_ballCarryType': 'ball_carry_type',
    'ballCarry_betterOption': 'ball_carry_better_option',
    'ballCarry_betterOptionPlayer': 'ball_carry_better_option_player',
    'ballCarry_betterOptionPlayer_id': 'ball_carry_better_option_player_id',
    'ballCarry_betterOptionTime': 'ball_carry_better_option_time',
    'ballCarry_betterOptionType': 'ball_carry_better_option_type',
    'ballCarry_carryIntent': 'ball_carry_intent',
    'ballCarry_carryType': 'ball_carry_type',
    'ballCarry_challengerPlayer': 'ball_carry_challenger_player',
    'ballCarry_clearerPlayer': 'ball_carry_clearer_player',
    'ballCarry_createsSpace': 'ball_carry_creates_space',
    'ballCarry_defenderPlayer': 'ball_carry_defender_player',
    'ballCarry_defenderPlayer_id': 'ball_carry_defender_player_id',
    'ballCarry_defenderPointX': 'ball_carry_defender_point_x',
    'ballCarry_defenderPointY': 'ball_carry_defender_point_y',
    'ballCarry_dribbleEndPointX': 'ball_carry_dribble_end_point_x',
    'ballCarry_dribbleEndPointY': 'ball_carry_dribble_end_point_y',
    'ballCarry_dribbleOutcomeType': 'ball_carry_dribble_outcome_type',
    'ballCarry_dribbleStartPointX': 'ball_carry_dribble_start_point_x',
    'ballCarry_dribbleStartPointY': 'ball_carry_dribble_start_point_y',
    'ballCarry_dribbleType': 'ball_carry_dribble_type',
    'ballCarry_gameEvent_id': 'ball_carry_game_event_id',
    'ballCarry_game_id': 'ball_carry_game_id',
    'ballCarry_id': 'ball_carry_id',
    'ballCarry_keeperPlayer': 'ball_carry_keeper_player',
    'ballCarry_late': 'ball_carry_late',
    'ballCarry_linesBrokenType': 'ball_carry_lines_broken_type',
    'ballCarry_missedTouchPlayer': 'ball_carry_missed_touch_player',
    'ballCarry_missedTouchPointX': 'ball_carry_missed_touch_point_x',
    'ballCarry_missedTouchPointY': 'ball_carry_missed_touch_point_y',
    'ballCarry_missedTouchType': 'ball_carry_missed_touch_type',
    'ballCarry_opportunityType': 'ball_carry_opportunity_type',
    'ballCarry_period': 'ball_carry_period',
    'ballCarry_possessionEvent_id': 'ball_carry_possession_event_id',
    'ballCarry_pressurePlayer': 'ball_carry_pressure_player',
    'ballCarry_pressurePlayer_id': 'ball_carry_pressure_player_id',
    'ballCarry_pressureType': 'ball_carry_pressure_type',
    'ballCarry_saveReboundType': 'ball_carry_save_rebound_type',
    'ballCarry_saveable': 'ball_carry_saveable',
    'ballCarry_shotInitialHeightType': 'ball_carry_shot_initial_height_type',
    'ballCarry_shotOutcomeType': 'ball_carry_shot_outcome_type',
    'ballCarry_successful': 'ball_carry_successful',
    'ballCarry_tackleAttemptPointX': 'ball_carry_tackle_attempt_point_x',
    'ballCarry_tackleAttemptPointY': 'ball_carry_tackle_attempt_point_y',
    'ballCarry_tackleAttemptType': 'ball_carry_tackle_attempt_type',
    'ballCarry_touchOutcomePlayer': 'ball_carry_touch_outcome_player',
    'ballCarry_touchOutcomeType': 'ball_carry_touch_outcome_type',
    'ballCarry_touchPointX': 'ball_carry_touch_point_x',
    'ballCarry_touchPointY': 'ball_carry_touch_point_y',
    'ballCarry_touchType': 'ball_carry_touch_type',
    'ballCarry_trickType': 'ball_carry_trick_type',
    # Challenge fields
    'challenge_additionalChallenger1': 'challenge_additional_challenger_1',
    'challenge_additionalChallenger2': 'challenge_additional_challenger_2',
    'challenge_additionalChallenger3': 'challenge_additional_challenger_3',
    'challenge_advantageType': 'challenge_advantage_type',
    'challenge_ballCarrierPlayer': 'challenge_ball_carrier_player',
    'challenge_ballCarrierPlayer_id': 'challenge_ball_carrier_player_id',
    'challenge_carryType': 'challenge_carry_type',
    'challenge_challengeOutcomeType': 'challenge_outcome_type',
    'challenge_challengePointX': 'challenge_point_x',
    'challenge_challengePointY': 'challenge_point_y',
    'challenge_challengeType': 'challenge_type',
    'challenge_challengeWinnerPlayer': 'challenge_winner_player',
    'challenge_challengeWinnerPlayer_id': 'challenge_winner_player_id',
    'challenge_challengerAwayPlayer': 'challenge_challenger_away_player',
    'challenge_challengerAwayPlayer_id': 'challenge_challenger_away_player_id',
    'challenge_challengerHomePlayer': 'challenge_challenger_home_player',
    'challenge_challengerHomePlayer_id': 'challenge_challenger_home_player_id',
    'challenge_challengerPlayer': 'challenge_challenger_player',
    'challenge_challengerPlayer_id': 'challenge_challenger_player_id',
    'challenge_createsSpace': 'challenge_creates_space',
    'challenge_dribbleEndPointX': 'challenge_dribble_end_point_x',
    'challenge_dribbleEndPointY': 'challenge_dribble_end_point_y',
    'challenge_dribbleStartPointX': 'challenge_dribble_start_point_x',
    'challenge_dribbleStartPointY': 'challenge_dribble_start_point_y',
    'challenge_dribbleType': 'challenge_dribble_type',
    'challenge_gameEvent_id': 'challenge_game_event_id',
    'challenge_game_id': 'challenge_game_id',
    'challenge_id': 'challenge_id',
    'challenge_insertedAt': 'challenge_inserted_at',
    'challenge_keeperPlayer': 'challenge_keeper_player',
    'challenge_linesBrokenType': 'challenge_lines_broken_type',
    'challenge_missedTouchPlayer': 'challenge_missed_touch_player',
    'challenge_missedTouchPointX': 'challenge_missed_touch_point_x',
    'challenge_missedTouchPointY': 'challenge_missed_touch_point_y',
    'challenge_missedTouchType': 'challenge_missed_touch_type',
    'challenge_opportunityType': 'challenge_opportunity_type',
    'challenge_period': 'challenge_period',
    'challenge_possessionEvent_id': 'challenge_possession_event_id',
    'challenge_pressurePlayer': 'challenge_pressure_player',
    'challenge_tackleAttemptPointX': 'challenge_tackle_attempt_point_x',
    'challenge_tackleAttemptPointY': 'challenge_tackle_attempt_point_y',
    'challenge_tackleAttemptType': 'challenge_tackle_attempt_type',
    'challenge_trickType': 'challenge_trick_type',
    # Clearance fields
    'clearance_advantageType': 'clearance_advantage_type',
    'clearance_badParry': 'clearance_bad_parry',
    'clearance_ballHeightType': 'clearance_ball_height_type',
    'clearance_ballHighPointType': 'clearance_ball_high_point_type',
    'clearance_betterOption': 'clearance_better_option',
    'clearance_betterOptionPlayer': 'clearance_better_option_player',
    'clearance_betterOptionPlayer_id': 'clearance_better_option_player_id',
    'clearance_betterOptionTime': 'clearance_better_option_time',
    'clearance_betterOptionType': 'clearance_better_option_type',
    'clearance_blockerPlayer': 'clearance_blocker_player',
    'clearance_blockerPlayer_id': 'clearance_blocker_player_id',
    'clearance_clearanceBodyType': 'clearance_body_type',
    'clearance_clearanceEndPointX': 'clearance_end_point_x',
    'clearance_clearanceEndPointY': 'clearance_end_point_y',
    'clearance_clearanceOutcomeType': 'clearance_outcome_type',
    'clearance_clearancePlayer_id': 'clearance_player_id',
    'clearance_clearancePointX': 'clearance_point_x',
    'clearance_clearancePointY': 'clearance_point_y',
    'clearance_clearanceStartPointX': 'clearance_start_point_x',
    'clearance_clearanceStartPointY': 'clearance_start_point_y',
    'clearance_clearerPlayer': 'clearance_clearer_player',
    'clearance_createsSpace': 'clearance_creates_space',
    'clearance_createsSpaceVsPlayer': 'clearance_creates_space_vs_player',
    'clearance_defenderPlayer': 'clearance_defender_player',
    'clearance_failedInterventionPlayer': 'clearance_failed_intervention_player',
    'clearance_failedInterventionPlayer1': 'clearance_failed_intervention_player_1',
    'clearance_failedInterventionPlayer2': 'clearance_failed_intervention_player_2',
    'clearance_failedInterventionPlayer3': 'clearance_failed_intervention_player_3',
    'clearance_failedInterventionPlayer_id': 'clearance_failed_intervention_player_id',
    'clearance_gameEvent_id': 'clearance_game_event_id',
    'clearance_game_id': 'clearance_game_id',
    'clearance_heightType': 'clearance_height_type',
    'clearance_id': 'clearance_id',
    'clearance_keeperPlayer': 'clearance_keeper_player',
    'clearance_late': 'clearance_late',
    'clearance_missedTouchPlayer': 'clearance_missed_touch_player',
    'clearance_missedTouchPointX': 'clearance_missed_touch_point_x',
    'clearance_missedTouchPointY': 'clearance_missed_touch_point_y',
    'clearance_missedTouchType': 'clearance_missed_touch_type',
    'clearance_opportunityType': 'clearance_opportunity_type',
    'clearance_period': 'clearance_period',
    'clearance_possessionEvent_id': 'clearance_possession_event_id',
    'clearance_pressurePlayer': 'clearance_pressure_player',
    'clearance_pressurePlayer_id': 'clearance_pressure_player_id',
    'clearance_pressureType': 'clearance_pressure_type',
    'clearance_saveReboundType': 'clearance_save_rebound_type',
    'clearance_saveable': 'clearance_saveable',
    'clearance_shotInitialHeightType': 'clearance_shot_initial_height_type',
    'clearance_shotOutcomeType': 'clearance_shot_outcome_type',
    # Cross fields
    'cross_advantageType': 'cross_advantage_type',
    'cross_badParry': 'cross_bad_parry',
    'cross_ballHeightType': 'cross_ball_height_type',
    'cross_betterOption': 'cross_better_option',
    'cross_betterOptionPlayer': 'cross_better_option_player',
    'cross_betterOptionTime': 'cross_better_option_time',
    'cross_betterOptionType': 'cross_better_option_type',
    'cross_blockerPlayer': 'cross_blocker_player',
    'cross_blockerPlayer_id': 'cross_blocker_player_id',
    'cross_clearerPlayer': 'cross_clearer_player',
    'cross_completeToPlayer': 'cross_complete_to_player',
    'cross_completeToPlayer_id': 'cross_complete_to_player_id',
    'cross_createsSpace': 'cross_creates_space',
    'cross_createsSpaceVsPlayer': 'cross_creates_space_vs_player',
    'cross_createsSpaceVsPlayer_id': 'cross_creates_space_vs_player_id',
    'cross_crossAccuracyType': 'cross_accuracy_type',
    'cross_crossEndPointX': 'cross_end_point_x',
    'cross_crossEndPointY': 'cross_end_point_y',
    'cross_crossHighPointType': 'cross_high_point_type',
    'cross_crossOutcomeType': 'cross_outcome_type',
    'cross_crossPointX': 'cross_point_x',
    'cross_crossPointY': 'cross_point_y',
    'cross_crossStartPointX': 'cross_start_point_x',
    'cross_crossStartPointY': 'cross_start_point_y',
    'cross_crossType': 'cross_type',
    'cross_crossZoneType': 'cross_zone_type',
    'cross_crosserBodyType': 'cross_body_type',
    'cross_crosserPlayer_id': 'cross_player_id',
    'cross_defenderBallHeightType': 'cross_defender_ball_height_type',
    'cross_defenderBodyType': 'cross_defender_body_type',
    'cross_defenderPlayer': 'cross_defender_player',
    'cross_defenderPlayer_id': 'cross_defender_player_id',
    'cross_deflectionPointX': 'cross_deflection_point_x',
    'cross_deflectionPointY': 'cross_deflection_point_y',
    'cross_deflectorBodyType': 'cross_deflector_body_type',
    'cross_deflectorPlayer': 'cross_deflector_player',
    'cross_deflectorPlayer_id': 'cross_deflector_player_id',
    'cross_failedInterventionPlayer': 'cross_failed_intervention_player',
    'cross_failedInterventionPlayer1': 'cross_failed_intervention_player_1',
    'cross_failedInterventionPlayer2': 'cross_failed_intervention_player_2',
    'cross_failedInterventionPlayer3': 'cross_failed_intervention_player_3',
    'cross_failedInterventionPlayer_id': 'cross_failed_intervention_player_id',
    'cross_failedInterventionPointX': 'cross_failed_intervention_point_x',
    'cross_failedInterventionPointY': 'cross_failed_intervention_point_y',
    'cross_gameEvent_id': 'cross_game_event_id',
    'cross_game_id': 'cross_game_id',
    'cross_goalkeeperPointX': 'cross_goalkeeper_point_x',
    'cross_goalkeeperPointY': 'cross_goalkeeper_point_y',
    'cross_id': 'cross_id',
    'cross_incompletionReasonType': 'cross_incompletion_reason_type',
    'cross_intendedTargetPlayer': 'cross_intended_target_player',
    'cross_intendedTargetPlayer_id': 'cross_intended_target_player_id',
    'cross_intendedTargetPointX': 'cross_intended_target_point_x',
    'cross_intendedTargetPointY': 'cross_intended_target_point_y',
    'cross_keeperPlayer': 'cross_keeper_player',
    'cross_late': 'cross_late',
    'cross_linesBrokenType': 'cross_lines_broken_type',
    'cross_missedTouchPlayer': 'cross_missed_touch_player',
    'cross_missedTouchPlayer_id': 'cross_missed_touch_player_id',
    'cross_missedTouchPointX': 'cross_missed_touch_point_x',
    'cross_missedTouchPointY': 'cross_missed_touch_point_y',
    'cross_missedTouchType': 'cross_missed_touch_type',
    'cross_noLook': 'cross_no_look',
    'cross_opportunityType': 'cross_opportunity_type',
    'cross_period': 'cross_period',
    'cross_possessionEvent_id': 'cross_possession_event_id',
    'cross_pressurePlayer': 'cross_pressure_player',
    'cross_pressurePlayer_id': 'cross_pressure_player_id',
    'cross_pressureType': 'cross_pressure_type',
    'cross_receiverBallHeightType': 'cross_receiver_ball_height_type',
    'cross_receiverBodyType': 'cross_receiver_body_type',
    'cross_receiverPointX': 'cross_receiver_point_x',
    'cross_receiverPointY': 'cross_receiver_point_y',
    'cross_saveReboundType': 'cross_save_rebound_type',
    'cross_saveable': 'cross_saveable',
    'cross_secondIncompletionReasonType': 'cross_second_incompletion_reason_type',
    'cross_shotInitialHeightType': 'cross_shot_initial_height_type',
    'cross_shotOutcomeType': 'cross_shot_outcome_type',
    'cross_targetZonePointX': 'cross_target_zone_point_x',
    'cross_targetZonePointY': 'cross_target_zone_point_y',
    # Foul fields
    'foul_badCall': 'foul_bad_call',
    'foul_correctDecision': 'foul_correct_decision',
    'foul_culpritPlayer_id': 'foul_culprit_player_id',
    'foul_foulOutcomeType': 'foul_outcome_type',
    'foul_foulPointX': 'foul_point_x',
    'foul_foulPointY': 'foul_point_y',
    'foul_foulType': 'foul_type',
    'foul_gameEvent_id': 'foul_game_event_id',
    'foul_game_id': 'foul_game_id',
    'foul_id': 'foul_id',
    'foul_possessionEvent_id': 'foul_possession_event_id',
    'foul_potentialOffenseType': 'foul_potential_offense_type',
    'foul_sequence': 'foul_sequence',
    'foul_tacticalFoul': 'foul_tactical',
    'foul_var': 'foul_var',
    'foul_varCulpritPlayer': 'foul_var_culprit_player',
    'foul_varOutcomeType': 'foul_var_outcome_type',
    'foul_varPotentialOffenseType': 'foul_var_potential_offense_type',
    'foul_varReasonType': 'foul_var_reason_type',
    'foul_victimPlayer': 'foul_victim_player',
    'foul_victimPlayer_id': 'foul_victim_player_id',
    # Passing fields
    'passing_advantageType': 'passing_advantage_type',
    'passing_badParry': 'passing_bad_parry',
    'passing_ballHeightType': 'passing_ball_height_type',
    'passing_betterOption': 'passing_better_option',
    'passing_betterOptionPlayer': 'passing_better_option_player',
    'passing_betterOptionPlayer_id': 'passing_better_option_player_id',
    'passing_betterOptionTime': 'passing_better_option_time',
    'passing_betterOptionType': 'passing_better_option_type',
    'passing_blockerPlayer': 'passing_blocker_player',
    'passing_blockerPlayer_id': 'passing_blocker_player_id',
    'passing_clearerPlayer': 'passing_clearer_player',
    'passing_createsSpace': 'passing_creates_space',
    'passing_createsSpaceVsPlayer': 'passing_creates_space_vs_player',
    'passing_createsSpaceVsPlayer_id': 'passing_creates_space_vs_player_id',
    'passing_defenderBodyType': 'passing_defender_body_type',
    'passing_defenderHeightType': 'passing_defender_height_type',
    'passing_defenderPlayer': 'passing_defender_player',
    'passing_defenderPlayer_id': 'passing_defender_player_id',
    'passing_defenderPointX': 'passing_defender_point_x',
    'passing_defenderPointY': 'passing_defender_point_y',
    'passing_deflectionPointX': 'passing_deflection_point_x',
    'passing_deflectionPointY': 'passing_deflection_point_y',
    'passing_deflectorBodyType': 'passing_deflector_body_type',
    'passing_deflectorPlayer': 'passing_deflector_player',
    'passing_deflectorPlayer_id': 'passing_deflector_player_id',
    'passing_failedInterventionPlayer': 'passing_failed_intervention_player',
    'passing_failedInterventionPlayer1': 'passing_failed_intervention_player_1',
    'passing_failedInterventionPlayer2': 'passing_failed_intervention_player_2',
    'passing_failedInterventionPlayer3': 'passing_failed_intervention_player_3',
    'passing_failedInterventionPlayer_id': 'passing_failed_intervention_player_id',
    'passing_failedInterventionPointX': 'passing_failed_intervention_point_x',
    'passing_failedInterventionPointY': 'passing_failed_intervention_point_y',
    'passing_gameEvent_id': 'passing_game_event_id',
    'passing_game_id': 'passing_game_id',
    'passing_goalkeeperPointX': 'passing_goalkeeper_point_x',
    'passing_goalkeeperPointY': 'passing_goalkeeper_point_y',
    'passing_id': 'passing_id',
    'passing_incompletionReasonType': 'passing_incompletion_reason_type',
    'passing_keeperPlayer': 'passing_keeper_player',
    'passing_late': 'passing_late',
    'passing_linesBrokenType': 'passing_lines_broken_type',
    'passing_missedTouchPlayer': 'passing_missed_touch_player',
    'passing_missedTouchPlayer_id': 'passing_missed_touch_player_id',
    'passing_missedTouchPointX': 'passing_missed_touch_point_x',
    'passing_missedTouchPointY': 'passing_missed_touch_point_y',
    'passing_missedTouchType': 'passing_missed_touch_type',
    'passing_noLook': 'passing_no_look',
    'passing_onTarget': 'passing_on_target',
    'passing_opportunityType': 'passing_opportunity_type',
    'passing_outOfPlayPointX': 'passing_out_of_play_point_x',
    'passing_outOfPlayPointY': 'passing_out_of_play_point_y',
    'passing_passerPlayer_id': 'passing_passer_player_id',
    'passing_passBodyType': 'passing_body_type',
    'passing_passHighPointType': 'passing_high_point_type',
    'passing_passOutcomeType': 'passing_outcome_type',
    'passing_passPointX': 'passing_point_x',
    'passing_passPointY': 'passing_point_y',
    'passing_passType': 'passing_type',
    'passing_passAccuracyType': 'passing_accuracy_type',
    'passing_period': 'passing_period',
    'passing_possessionEvent_id': 'passing_possession_event_id',
    'passing_pressurePlayer': 'passing_pressure_player',
    'passing_pressurePlayer_id': 'passing_pressure_player_id',
    'passing_pressureType': 'passing_pressure_type',
    'passing_receiverBodyType': 'passing_receiver_body_type',
    'passing_receiverFacingType': 'passing_receiver_facing_type',
    'passing_receiverHeightType': 'passing_receiver_height_type',
    'passing_receiverPlayer': 'passing_receiver_player',
    'passing_receiverPlayer_id': 'passing_receiver_player_id',
    'passing_receiverPointX': 'passing_receiver_point_x',
    'passing_receiverPointY': 'passing_receiver_point_y',
    'passing_saveReboundType': 'passing_save_rebound_type',
    'passing_saveable': 'passing_saveable',
    'passing_secondIncompletionReasonType': 'passing_second_incompletion_reason_type',
    'passing_shotInitialHeightType': 'passing_shot_initial_height_type',
    'passing_shotOutcomeType': 'passing_shot_outcome_type',
    'passing_targetFacingType': 'passing_target_facing_type',
    'passing_targetPlayer_id': 'passing_target_player_id',
    'passing_targetPointX': 'passing_target_point_x',
    'passing_targetPointY': 'passing_target_point_y',
    # Rebound fields
    'rebound_advantageType': 'rebound_advantage_type',
    'rebound_badParry': 'rebound_bad_parry',
    'rebound_blockerPlayer': 'rebound_blocker_player',
    'rebound_defenderPlayer': 'rebound_defender_player',
    'rebound_gameEvent_id': 'rebound_game_event_id',
    'rebound_game_id': 'rebound_game_id',
    'rebound_id': 'rebound_id',
    'rebound_keeperPlayer': 'rebound_keeper_player',
    'rebound_missedTouchPlayer': 'rebound_missed_touch_player',
    'rebound_missedTouchPointX': 'rebound_missed_touch_point_x',
    'rebound_missedTouchPointY': 'rebound_missed_touch_point_y',
    'rebound_missedTouchType': 'rebound_missed_touch_type',
    'rebound_originateType': 'rebound_originate_type',
    'rebound_period': 'rebound_period',
    'rebound_possessionEvent_id': 'rebound_possession_event_id',
    'rebound_reboundBodyType': 'rebound_body_type',
    'rebound_reboundEndPointX': 'rebound_end_point_x',
    'rebound_reboundEndPointY': 'rebound_end_point_y',
    'rebound_reboundHeightType': 'rebound_height_type',
    'rebound_reboundHighPointType': 'rebound_high_point_type',
    'rebound_reboundOutcomeType': 'rebound_outcome_type',
    'rebound_reboundPointX': 'rebound_point_x',
    'rebound_reboundPointY': 'rebound_point_y',
    'rebound_reboundStartPointX': 'rebound_start_point_x',
    'rebound_reboundStartPointY': 'rebound_start_point_y',
    'rebound_rebounderPlayer_id': 'rebound_player_id',
    'rebound_saveReboundType': 'rebound_save_rebound_type',
    'rebound_saveable': 'rebound_saveable',
    'rebound_shotInitialHeightType': 'rebound_shot_initial_height_type',
    'rebound_shotOutcomeType': 'rebound_shot_outcome_type',
    # Shooting fields
    'shooting_advantageType': 'shooting_advantage_type',
    'shooting_badParry': 'shooting_bad_parry',
    'shooting_ballHeightType': 'shooting_ball_height_type',
    'shooting_ballMoving': 'shooting_ball_moving',
    'shooting_betterOption': 'shooting_better_option',
    'shooting_betterOptionPlayer': 'shooting_better_option_player',
    'shooting_betterOptionPlayer_id': 'shooting_better_option_player_id',
    'shooting_betterOptionTime': 'shooting_better_option_time',
    'shooting_betterOptionType': 'shooting_better_option_type',
    'shooting_blockerPlayer': 'shooting_blocker_player',
    'shooting_blockerPlayer_id': 'shooting_blocker_player_id',
    'shooting_bodyMovementType': 'shooting_body_movement_type',
    'shooting_clearerPlayer': 'shooting_clearer_player',
    'shooting_createsSpace': 'shooting_creates_space',
    'shooting_createsSpaceVsPlayer': 'shooting_creates_space_vs_player',
    'shooting_createsSpaceVsPlayer_id': 'shooting_creates_space_vs_player_id',
    'shooting_defenderPointX': 'shooting_defender_point_x',
    'shooting_defenderPointY': 'shooting_defender_point_y',
    'shooting_deflectionPointX': 'shooting_deflection_point_x',
    'shooting_deflectionPointY': 'shooting_deflection_point_y',
    'shooting_deflectorBodyType': 'shooting_deflector_body_type',
    'shooting_deflectorPlayer': 'shooting_deflector_player',
    'shooting_failedInterventionPlayer': 'shooting_failed_intervention_player',
    'shooting_failedInterventionPlayer1': 'shooting_failed_intervention_player_1',
    'shooting_failedInterventionPlayer2': 'shooting_failed_intervention_player_2',
    'shooting_failedInterventionPlayer3': 'shooting_failed_intervention_player_3',
    'shooting_failedInterventionPlayer_id': 'shooting_failed_intervention_player_id',
    'shooting_gameEvent_id': 'shooting_game_event_id',
    'shooting_game_id': 'shooting_game_id',
    'shooting_goalLineEndPointX': 'shooting_goal_line_end_point_x',
    'shooting_goalLineEndPointY': 'shooting_goal_line_end_point_y',
    'shooting_goalLineStartPointX': 'shooting_goal_line_start_point_x',
    'shooting_goalLineStartPointY': 'shooting_goal_line_start_point_y',
    'shooting_goalkeeperPointX': 'shooting_goalkeeper_point_x',
    'shooting_goalkeeperPointY': 'shooting_goalkeeper_point_y',
    'shooting_id': 'shooting_id',
    'shooting_keeperTouchPointX': 'shooting_keeper_touch_point_x',
    'shooting_keeperTouchPointY': 'shooting_keeper_touch_point_y',
    'shooting_keeperTouchType': 'shooting_keeper_touch_type',
    'shooting_late': 'shooting_late',
    'shooting_missedTouchPlayer': 'shooting_missed_touch_player',
    'shooting_missedTouchPointX': 'shooting_missed_touch_point_x',
    'shooting_missedTouchPointY': 'shooting_missed_touch_point_y',
    'shooting_missedTouchType': 'shooting_missed_touch_type',
    'shooting_noLook': 'shooting_no_look',
    'shooting_period': 'shooting_period',
    'shooting_possessionEvent_id': 'shooting_possession_event_id',
    'shooting_pressurePlayer': 'shooting_pressure_player',
    'shooting_pressurePlayer_id': 'shooting_pressure_player_id',
    'shooting_pressureType': 'shooting_pressure_type',
    'shooting_saveHeightType': 'shooting_save_height_type',
    'shooting_savePointX': 'shooting_save_point_x',
    'shooting_savePointY': 'shooting_save_point_y',
    'shooting_saveReboundType': 'shooting_save_rebound_type',
    'shooting_saveable': 'shooting_saveable',
    'shooting_saverPlayer': 'shooting_saver_player',
    'shooting_saverPlayer_id': 'shooting_saver_player_id',
    'shooting_shooterPlayer_id': 'shooting_shooter_player_id',
    'shooting_shotBodyType': 'shooting_body_type',
    'shooting_shotInitialHeightType': 'shooting_initial_height_type',
    'shooting_shotNatureType': 'shooting_nature_type',
    'shooting_shotOutcomeType': 'shooting_outcome_type',
    'shooting_shotPointX': 'shooting_point_x',
    'shooting_shotPointY': 'shooting_point_y',
    'shooting_shotTargetPointX': 'shooting_target_point_x',
    'shooting_shotTargetPointY': 'shooting_target_point_y',
    'shooting_shotType': 'shooting_type',
}
