PFF_MATCH_INFO = [
    {
        'match_id': '3827',
        'date': '2022-11-24T19:00:00',
        'home_shortname': 'BRA',
        'away_shortname': 'SRB',
        'week': 1,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Brazil',
        'away_team_name': 'Serbia',
        'home_team_id': '361',
        'awayTeam.id': '375',
    },
    {
        'match_id': '3826',
        'date': '2022-11-24T16:00:00',
        'home_shortname': 'POR',
        'away_shortname': 'GHA',
        'week': 1,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Portugal',
        'away_team_name': 'Ghana',
        'home_team_id': '365',
        'awayTeam.id': '383',
    },
    {
        'match_id': '3825',
        'date': '2022-11-24T13:00:00',
        'home_shortname': 'URU',
        'away_shortname': 'KOR',
        'week': 1,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Uruguay',
        'away_team_name': 'South Korea',
        'home_team_id': '369',
        'awayTeam.id': '377',
    },
    {
        'match_id': '3824',
        'date': '2022-11-24T10:00:00',
        'home_shortname': 'SUI',
        'away_shortname': 'CMR',
        'week': 1,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Switzerland',
        'away_team_name': 'Cameroon',
        'home_team_id': '370',
        'awayTeam.id': '379',
    },
    {
        'match_id': '3823',
        'date': '2022-11-23T19:00:00',
        'home_shortname': 'BEL',
        'away_shortname': 'CAN',
        'week': 1,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Belgium',
        'away_team_name': 'Canada',
        'home_team_id': '362',
        'awayTeam.id': '380',
    },
    {
        'match_id': '3822',
        'date': '2022-11-23T16:00:00',
        'home_shortname': 'ESP',
        'away_shortname': 'CRC',
        'week': 1,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Spain',
        'away_team_name': 'Costa Rica',
        'home_team_id': '52',
        'awayTeam.id': '385',
    },
    {
        'match_id': '3821',
        'date': '2022-11-23T13:00:00',
        'home_shortname': 'GER',
        'away_shortname': 'JPN',
        'week': 1,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Germany',
        'away_team_name': 'Japan',
        'home_team_id': '368',
        'awayTeam.id': '57',
    },
    {
        'match_id': '3820',
        'date': '2022-11-23T10:00:00',
        'home_shortname': 'MAR',
        'away_shortname': 'CRO',
        'week': 1,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'Morocco',
        'away_team_name': 'Croatia',
        'home_team_id': '374',
        'awayTeam.id': '371',
    },
    {
        'match_id': '3819',
        'date': '2022-11-22T19:00:00',
        'home_shortname': 'FRA',
        'away_shortname': 'AUS',
        'week': 1,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'France',
        'away_team_name': 'Australia',
        'home_team_id': '363',
        'awayTeam.id': '386',
    },
    {
        'match_id': '3817',
        'date': '2022-11-22T13:00:00',
        'home_shortname': 'DEN',
        'away_shortname': 'TUN',
        'week': 1,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Denmark',
        'away_team_name': 'Tunisia',
        'home_team_id': '367',
        'awayTeam.id': '378',
    },
    {
        'match_id': '3816',
        'date': '2022-11-22T10:00:00',
        'home_shortname': 'ARG',
        'away_shortname': 'KSA',
        'week': 1,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Argentina',
        'away_team_name': 'Saudi Arabia',
        'home_team_id': '364',
        'awayTeam.id': '382',
    },
    {
        'match_id': '3815',
        'date': '2022-11-21T19:00:00',
        'home_shortname': 'USA',
        'away_shortname': 'WAL',
        'week': 1,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'United States',
        'away_team_name': 'Wales',
        'home_team_id': '51',
        'awayTeam.id': '384',
    },
    {
        'match_id': '3814',
        'date': '2022-11-20T16:00:00',
        'home_shortname': 'QAT',
        'away_shortname': 'ECU',
        'week': 1,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'Qatar',
        'away_team_name': 'Ecuador',
        'home_team_id': '360',
        'awayTeam.id': '381',
    },
    {
        'match_id': '3813',
        'date': '2022-11-21T13:00:00',
        'home_shortname': 'ENG',
        'away_shortname': 'IRN',
        'week': 1,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'England',
        'away_team_name': 'Iran',
        'home_team_id': '50',
        'awayTeam.id': '373',
    },
    {
        'match_id': '3812',
        'date': '2022-11-21T16:00:00',
        'home_shortname': 'SEN',
        'away_shortname': 'NED',
        'week': 1,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Senegal',
        'away_team_name': 'Netherlands',
        'home_team_id': '372',
        'awayTeam.id': '366',
    },
    {
        'match_id': '3818',
        'date': '2022-11-22T16:00:00',
        'home_shortname': 'MEX',
        'away_shortname': 'POL',
        'week': 1,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Mexico',
        'away_team_name': 'Poland',
        'home_team_id': '58',
        'awayTeam.id': '376',
    },
    {
        'match_id': '3841',
        'date': '2022-11-28T13:00:00',
        'home_shortname': 'KOR',
        'away_shortname': 'GHA',
        'week': 2,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'South Korea',
        'away_team_name': 'Ghana',
        'home_team_id': '377',
        'awayTeam.id': '383',
    },
    {
        'match_id': '3839',
        'date': '2022-11-27T19:00:00',
        'home_shortname': 'ESP',
        'away_shortname': 'GER',
        'week': 2,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'Spain',
        'away_team_name': 'Germany',
        'home_team_id': '52',
        'awayTeam.id': '368',
    },
    {
        'match_id': '3838',
        'date': '2022-11-27T16:00:00',
        'home_shortname': 'CRO',
        'away_shortname': 'CAN',
        'week': 2,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Croatia',
        'away_team_name': 'Canada',
        'home_team_id': '371',
        'awayTeam.id': '380',
    },
    {
        'match_id': '3837',
        'date': '2022-11-27T13:00:00',
        'home_shortname': 'BEL',
        'away_shortname': 'MAR',
        'week': 2,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Belgium',
        'away_team_name': 'Morocco',
        'home_team_id': '362',
        'awayTeam.id': '374',
    },
    {
        'match_id': '3836',
        'date': '2022-11-27T10:00:00',
        'home_shortname': 'JPN',
        'away_shortname': 'CRC',
        'week': 2,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Japan',
        'away_team_name': 'Costa Rica',
        'home_team_id': '57',
        'awayTeam.id': '385',
    },
    {
        'match_id': '3835',
        'date': '2022-11-26T19:00:00',
        'home_shortname': 'ARG',
        'away_shortname': 'MEX',
        'week': 2,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Argentina',
        'away_team_name': 'Mexico',
        'home_team_id': '364',
        'awayTeam.id': '58',
    },
    {
        'match_id': '3840',
        'date': '2022-11-28T10:00:00',
        'home_shortname': 'CMR',
        'away_shortname': 'SRB',
        'week': 2,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Cameroon',
        'away_team_name': 'Serbia',
        'home_team_id': '379',
        'awayTeam.id': '375',
    },
    {
        'match_id': '3834',
        'date': '2022-11-26T16:00:00',
        'home_shortname': 'FRA',
        'away_shortname': 'DEN',
        'week': 2,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'France',
        'away_team_name': 'Denmark',
        'home_team_id': '363',
        'awayTeam.id': '367',
    },
    {
        'match_id': '3833',
        'date': '2022-11-26T13:00:00',
        'home_shortname': 'POL',
        'away_shortname': 'KSA',
        'week': 2,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Poland',
        'away_team_name': 'Saudi Arabia',
        'home_team_id': '376',
        'awayTeam.id': '382',
    },
    {
        'match_id': '3832',
        'date': '2022-11-26T10:00:00',
        'home_shortname': 'TUN',
        'away_shortname': 'AUS',
        'week': 2,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Tunisia',
        'away_team_name': 'Australia',
        'home_team_id': '378',
        'awayTeam.id': '386',
    },
    {
        'match_id': '3831',
        'date': '2022-11-25T19:00:00',
        'home_shortname': 'ENG',
        'away_shortname': 'USA',
        'week': 2,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'England',
        'away_team_name': 'United States',
        'home_team_id': '50',
        'awayTeam.id': '51',
    },
    {
        'match_id': '3830',
        'date': '2022-11-25T16:00:00',
        'home_shortname': 'NED',
        'away_shortname': 'ECU',
        'week': 2,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Netherlands',
        'away_team_name': 'Ecuador',
        'home_team_id': '366',
        'awayTeam.id': '381',
    },
    {
        'match_id': '3829',
        'date': '2022-11-25T13:00:00',
        'home_shortname': 'QAT',
        'away_shortname': 'SEN',
        'week': 2,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Qatar',
        'away_team_name': 'Senegal',
        'home_team_id': '360',
        'awayTeam.id': '372',
    },
    {
        'match_id': '3828',
        'date': '2022-11-25T10:00:00',
        'home_shortname': 'WAL',
        'away_shortname': 'IRN',
        'week': 2,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Wales',
        'away_team_name': 'Iran',
        'home_team_id': '384',
        'awayTeam.id': '373',
    },
    {
        'match_id': '3843',
        'date': '2022-11-28T19:00:00',
        'home_shortname': 'POR',
        'away_shortname': 'URU',
        'week': 2,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Portugal',
        'away_team_name': 'Uruguay',
        'home_team_id': '365',
        'awayTeam.id': '369',
    },
    {
        'match_id': '3842',
        'date': '2022-11-28T16:00:00',
        'home_shortname': 'BRA',
        'away_shortname': 'SUI',
        'week': 2,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Brazil',
        'away_team_name': 'Switzerland',
        'home_team_id': '361',
        'awayTeam.id': '370',
    },
    {
        'match_id': '3844',
        'date': '2022-11-29T15:00:00',
        'home_shortname': 'ECU',
        'away_shortname': 'SEN',
        'week': 3,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Ecuador',
        'away_team_name': 'Senegal',
        'home_team_id': '381',
        'awayTeam.id': '372',
    },
    {
        'match_id': '3855',
        'date': '2022-12-01T19:00:00',
        'home_shortname': 'CRC',
        'away_shortname': 'GER',
        'week': 3,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'Costa Rica',
        'away_team_name': 'Germany',
        'home_team_id': '385',
        'awayTeam.id': '368',
    },
    {
        'match_id': '3854',
        'date': '2022-12-01T19:00:00',
        'home_shortname': 'JPN',
        'away_shortname': 'ESP',
        'week': 3,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Japan',
        'away_team_name': 'Spain',
        'home_team_id': '57',
        'awayTeam.id': '52',
    },
    {
        'match_id': '3853',
        'date': '2022-12-01T15:00:00',
        'home_shortname': 'CAN',
        'away_shortname': 'MAR',
        'week': 3,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Canada',
        'away_team_name': 'Morocco',
        'home_team_id': '380',
        'awayTeam.id': '374',
    },
    {
        'match_id': '3852',
        'date': '2022-12-01T15:00:00',
        'home_shortname': 'CRO',
        'away_shortname': 'BEL',
        'week': 3,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Croatia',
        'away_team_name': 'Belgium',
        'home_team_id': '371',
        'awayTeam.id': '362',
    },
    {
        'match_id': '3851',
        'date': '2022-11-30T19:00:00',
        'home_shortname': 'KSA',
        'away_shortname': 'MEX',
        'week': 3,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Saudi Arabia',
        'away_team_name': 'Mexico',
        'home_team_id': '382',
        'awayTeam.id': '58',
    },
    {
        'match_id': '3850',
        'date': '2022-11-30T19:00:00',
        'home_shortname': 'POL',
        'away_shortname': 'ARG',
        'week': 3,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Poland',
        'away_team_name': 'Argentina',
        'home_team_id': '376',
        'awayTeam.id': '364',
    },
    {
        'match_id': '3849',
        'date': '2022-11-30T15:00:00',
        'home_shortname': 'TUN',
        'away_shortname': 'FRA',
        'week': 3,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Tunisia',
        'away_team_name': 'France',
        'home_team_id': '378',
        'awayTeam.id': '363',
    },
    {
        'match_id': '3848',
        'date': '2022-11-30T15:00:00',
        'home_shortname': 'AUS',
        'away_shortname': 'DEN',
        'week': 3,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Australia',
        'away_team_name': 'Denmark',
        'home_team_id': '386',
        'awayTeam.id': '367',
    },
    {
        'match_id': '3847',
        'date': '2022-11-29T19:00:00',
        'home_shortname': 'IRN',
        'away_shortname': 'USA',
        'week': 3,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Iran',
        'away_team_name': 'United States',
        'home_team_id': '373',
        'awayTeam.id': '51',
    },
    {
        'match_id': '3846',
        'date': '2022-11-29T19:00:00',
        'home_shortname': 'WAL',
        'away_shortname': 'ENG',
        'week': 3,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Wales',
        'away_team_name': 'England',
        'home_team_id': '384',
        'awayTeam.id': '50',
    },
    {
        'match_id': '3845',
        'date': '2022-11-29T15:00:00',
        'home_shortname': 'NED',
        'away_shortname': 'QAT',
        'week': 3,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'Netherlands',
        'away_team_name': 'Qatar',
        'home_team_id': '366',
        'awayTeam.id': '360',
    },
    {
        'match_id': '3856',
        'date': '2022-12-02T15:00:00',
        'home_shortname': 'GHA',
        'away_shortname': 'URU',
        'week': 3,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Ghana',
        'away_team_name': 'Uruguay',
        'home_team_id': '383',
        'awayTeam.id': '369',
    },
    {
        'match_id': '3857',
        'date': '2022-12-02T15:00:00',
        'home_shortname': 'KOR',
        'away_shortname': 'POR',
        'week': 3,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'South Korea',
        'away_team_name': 'Portugal',
        'home_team_id': '377',
        'awayTeam.id': '365',
    },
    {
        'match_id': '3859',
        'date': '2022-12-02T19:00:00',
        'home_shortname': 'CMR',
        'away_shortname': 'BRA',
        'week': 3,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Cameroon',
        'away_team_name': 'Brazil',
        'home_team_id': '379',
        'awayTeam.id': '361',
    },
    {
        'match_id': '3858',
        'date': '2022-12-02T19:00:00',
        'home_shortname': 'SRB',
        'away_shortname': 'SUI',
        'week': 3,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Serbia',
        'away_team_name': 'Switzerland',
        'home_team_id': '375',
        'awayTeam.id': '370',
    },
    {
        'match_id': '10509',
        'date': '2022-12-06T19:00:00',
        'home_shortname': 'POR',
        'away_shortname': 'SUI',
        'week': 4,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Portugal',
        'away_team_name': 'Switzerland',
        'home_team_id': '365',
        'awayTeam.id': '370',
    },
    {
        'match_id': '10503',
        'date': '2022-12-03T19:00:00',
        'home_shortname': 'ARG',
        'away_shortname': 'AUS',
        'week': 4,
        'stadium.name': 'Ahmad Bin Ali Stadium',
        'home_team_name': 'Argentina',
        'away_team_name': 'Australia',
        'home_team_id': '364',
        'awayTeam.id': '386',
    },
    {
        'match_id': '10504',
        'date': '2022-12-04T15:00:00',
        'home_shortname': 'FRA',
        'away_shortname': 'POL',
        'week': 4,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'France',
        'away_team_name': 'Poland',
        'home_team_id': '363',
        'awayTeam.id': '376',
    },
    {
        'match_id': '10505',
        'date': '2022-12-04T19:00:00',
        'home_shortname': 'ENG',
        'away_shortname': 'SEN',
        'week': 4,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'England',
        'away_team_name': 'Senegal',
        'home_team_id': '50',
        'awayTeam.id': '372',
    },
    {
        'match_id': '10506',
        'date': '2022-12-05T15:00:00',
        'home_shortname': 'JPN',
        'away_shortname': 'CRO',
        'week': 4,
        'stadium.name': 'Al Janoub Stadium',
        'home_team_name': 'Japan',
        'away_team_name': 'Croatia',
        'home_team_id': '57',
        'awayTeam.id': '371',
    },
    {
        'match_id': '10507',
        'date': '2022-12-05T19:00:00',
        'home_shortname': 'BRA',
        'away_shortname': 'KOR',
        'week': 4,
        'stadium.name': 'Stadium 974',
        'home_team_name': 'Brazil',
        'away_team_name': 'South Korea',
        'home_team_id': '361',
        'awayTeam.id': '377',
    },
    {
        'match_id': '10508',
        'date': '2022-12-06T15:00:00',
        'home_shortname': 'MAR',
        'away_shortname': 'ESP',
        'week': 4,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Morocco',
        'away_team_name': 'Spain',
        'home_team_id': '374',
        'awayTeam.id': '52',
    },
    {
        'match_id': '10502',
        'date': '2022-12-03T15:00:00',
        'home_shortname': 'NED',
        'away_shortname': 'USA',
        'week': 4,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Netherlands',
        'away_team_name': 'United States',
        'home_team_id': '366',
        'awayTeam.id': '51',
    },
    {
        'match_id': '10511',
        'date': '2022-12-09T19:00:00',
        'home_shortname': 'NED',
        'away_shortname': 'ARG',
        'week': 5,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Netherlands',
        'away_team_name': 'Argentina',
        'home_team_id': '366',
        'awayTeam.id': '364',
    },
    {
        'match_id': '10512',
        'date': '2022-12-10T15:00:00',
        'home_shortname': 'MAR',
        'away_shortname': 'POR',
        'week': 5,
        'stadium.name': 'Al Thumama Stadium',
        'home_team_name': 'Morocco',
        'away_team_name': 'Portugal',
        'home_team_id': '374',
        'awayTeam.id': '365',
    },
    {
        'match_id': '10513',
        'date': '2022-12-10T19:00:00',
        'home_shortname': 'ENG',
        'away_shortname': 'FRA',
        'week': 5,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'England',
        'away_team_name': 'France',
        'home_team_id': '50',
        'awayTeam.id': '363',
    },
    {
        'match_id': '10510',
        'date': '2022-12-09T15:00:00',
        'home_shortname': 'CRO',
        'away_shortname': 'BRA',
        'week': 5,
        'stadium.name': 'Education City Stadium',
        'home_team_name': 'Croatia',
        'away_team_name': 'Brazil',
        'home_team_id': '371',
        'awayTeam.id': '361',
    },
    {
        'match_id': '10514',
        'date': '2022-12-13T19:00:00',
        'home_shortname': 'ARG',
        'away_shortname': 'CRO',
        'week': 6,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Argentina',
        'away_team_name': 'Croatia',
        'home_team_id': '364',
        'awayTeam.id': '371',
    },
    {
        'match_id': '10515',
        'date': '2022-12-14T19:00:00',
        'home_shortname': 'FRA',
        'away_shortname': 'MAR',
        'week': 6,
        'stadium.name': 'Al Bayt Stadium',
        'home_team_name': 'France',
        'away_team_name': 'Morocco',
        'home_team_id': '363',
        'awayTeam.id': '374',
    },
    {
        'match_id': '10516',
        'date': '2022-12-17T15:00:00',
        'home_shortname': 'CRO',
        'away_shortname': 'MAR',
        'week': 7,
        'stadium.name': 'Khalifa International Stadium',
        'home_team_name': 'Croatia',
        'away_team_name': 'Morocco',
        'home_team_id': '371',
        'awayTeam.id': '374',
    },
    {
        'match_id': '10517',
        'date': '2022-12-18T15:00:00',
        'home_shortname': 'ARG',
        'away_shortname': 'FRA',
        'week': 8,
        'stadium.name': 'Lusail Stadium',
        'home_team_name': 'Argentina',
        'away_team_name': 'France',
        'home_team_id': '364',
        'awayTeam.id': '363',
    },
]

GDRIVE_FILE_IDS = {
    '3812': {
        'rosters': '1iHNONCqc6_Gf2GOvTvCIZopwUq8bXikX',
        'tracking': '1c1HdSrToX_0RfC92JkVy4ldRJ7M67JI7',
        'event': '1bqbLRZVzkkBS9DsijQf2km0iXFB8SYxD',
        'metadata': '1KYzyCxauhHZIfY_9nqvnAXi83aWr-23q',
    },
    '3813': {
        'rosters': '1FH1gHOf7k3Ee0IlBktZAqtFOdvP6WNxM',
        'tracking': '1efRLjG4KXgwBfVritso4VhyCEN2WGv9L',
        'event': '1-OQcnc3FGZUdQe1alX6hY4ZESCCTpryl',
        'metadata': '1Tc1h8rI985dq2DGmZCMa3W1OsN-E4Yuh',
    },
    '3814': {
        'rosters': '1hmszFCNZDZpZa0SOpJ2Vw3xby6MXwOHX',
        'tracking': '16to2wc6UeR2AYikZvQbdW_k0xpCIpAQB',
        'event': '1MyYEJLxG81zOR_GWQZvwYlYMQj6xPbhF',
        'metadata': '10iX17cHWFjAwmZoOCZD78mbNElgzdJho',
    },
    '3815': {
        'rosters': '1D8J2NZlPDLnCn2uqFBjewBTiJ1gzP41S',
        'tracking': '1m841qX2JpERv3z1Cx-D2T4xQDBYzdofH',
        'event': '1bWnkpv2YPAcinAdH3cOKYqMoTseRHUe9',
        'metadata': '1SRuJZoJq1Ix7WuoAhnfRMlxz1NoCJalM',
    },
    '3816': {
        'rosters': '1eaTKW1VdiZOEUnnjhrTfNmdrGhMuiCAp',
        'tracking': '1wxMkLuN5qNpGzqW9GOtcEfL35h_1D_-F',
        'event': '1hRRRxuguFalDIfGijyLv2dZcrhnVC6Xm',
        'metadata': '1ZP_xXNfn20wHCG84f-nTcwp6RgQOXmQZ',
    },
    '3817': {
        'rosters': '1ID9TBkGiIbl4V7vzE8QGkHGuWlqBwdnh',
        'tracking': '1mcyrcT6KafIlW1VCJdLxbaFSS7M1hCOb',
        'event': '1rMrptvv9MDoh66WZYx-fxTKG2VcIjIxP',
        'metadata': '1-ECKLzbTRw5Utqx-sUUYYRI1wMe_5eWy',
    },
    '3818': {
        'rosters': '1kVkje2ep_Zl2rwcOujo6LFQ6hJq19v2A',
        'tracking': '1K5lJk3kgfEZJe-4pFYxItSYcvVMuVlTa',
        'event': '141btxMGfC6kvM5aOU5v4oybJRpf3CcHV',
        'metadata': '1102koaeA-u-Ahz6wLKmlB-4_QfC16YhW',
    },
    '3819': {
        'rosters': '1MX6hOfImkgCbL4NcCx6Hf4gksgb8l4tR',
        'tracking': '1CG_hsnQrNYtV_rSsAJ_ljLy1h7QiVBal',
        'event': '1d_RSEFeGf5u8pQ11jADLbmylXKIH8yBq',
        'metadata': '1DAI_Bu0XSHmcjY114qqwP1WPDzJ7ettH',
    },
    '3820': {
        'rosters': '1AShogkWUf9kCwi4eh_YhjVor7yhowtIL',
        'tracking': '19qeCd4qs7U1k675z-FrOpWj3tgAO511k',
        'event': '18RIx1Klmw-IC3zbySpXU1fYEjwRnQNBS',
        'metadata': '1FwiVFF7qL3xUaRYANJN4ymDOXcQYfSir',
    },
    '3821': {
        'rosters': '1XpMGzcFlwHMTn_SNqXeT64H-6OaJwdoW',
        'tracking': '142pZZGX4yXrtCyZeU3QAYQgf_KTbKNWZ',
        'event': '1eqnKW0Y9Yjf3qqsjUGiOsftrdnEa3-pl',
        'metadata': '1loJUaSJFjNQUUGWJPJzThEJICR1jO13p',
    },
    '3822': {
        'rosters': '1abBBYHzhyNVLIoixVE4j9x3EmMkd0ya6',
        'tracking': '1sJwoRdLy_3mnd02BJM4xTLbZzRjQYOhZ',
        'event': '1nuIgAcYZvxAWxdqZ_5Me9um8NoYj5tvQ',
        'metadata': '18YFjE-zg1ziXkkllG0MEGyMGtOHoKeaF',
    },
    '3823': {
        'rosters': '1H8ZHoOZUssZe_s_aK2n4vUiw2Nphg4hK',
        'tracking': '1ipjYDk8XJer6Q0IyuaFHunWPAwLNrOSx',
        'event': '1Zsw8y9TmB7d0VTxKqbcv9clS9-FI9ocj',
        'metadata': '1X-fbj5VmaO8c5pFEVTHLoiERa-HGwi-p',
    },
    '3824': {
        'rosters': '1Ffn3I2X9jDdoyT7H3E7iFWofTqZDF9o-',
        'tracking': '1HGJs3zV1CjBVTqnAObtrl-w3aMm07Aaa',
        'event': '1A_DHihurMVT9hGL8pTzajOtWjvt1Np91',
        'metadata': '12ajSojq3bB8F3ZgmUF01-mcQOchewLlX',
    },
    '3825': {
        'rosters': '1IXUo3njQpgDlbrpctaHfY6EX_SWa5JAN',
        'tracking': '15MzFu2eAxw3O9QKoLJhhumc4SgsH6yAG',
        'event': '1I8VXediICIH-_WJSMMNQhe4Htm71KZlj',
        'metadata': '1QA_Ms_Jh9HT6vIYHe2qIdy_YgA-7vQjX',
    },
    '3826': {
        'rosters': '1Rrww9y682-r7blfVofI3wov86Ws15o24',
        'tracking': '1cCy9WvqUGw6gHhk1fd3qFTdjZ_iq2yX2',
        'event': '1aG4B5m0UwyFC8QLHWevG047IMXFBAS1v',
        'metadata': '1ovNm74I9D9Z-8a3UtcfhWxqf5I5TF6Ww',
    },
    '3827': {
        'rosters': '1ve594Khu-7LtAV5mjBN2XCdCAAsPnvcY',
        'tracking': '1eYp8Z0AAI8_LoHnQFKjFrsiuG8Dj9pTF',
        'event': '1vVPG--ZypuS7DCK0u4jtvmVIT8mWGoBU',
        'metadata': '1TzP9kMv7OKju9-utAS1XHNWT3YnKpVWN',
    },
    '3828': {
        'rosters': '1UebFFcxnDHhtMcP2oQzGnKYY_1m4MuBF',
        'tracking': '1l2SdBpsHWUftccy2gEwohIsdpdHy7S9H',
        'event': '1_8JHxyTwFP8RtTQw4zBOtLKWdved4D9F',
        'metadata': '1uysWds9Hz2YtAuPDqH3UH2xYY6kx96-w',
    },
    '3829': {
        'rosters': '1zZIuVsFlm-9IGOxopxbWRQga5gDXS7X9',
        'tracking': '1_YqwqayrT9mAyw0v6Hqn99dKRDA2dO3b',
        'event': '1nbiUMzqPtcUqa7_TuaF8m2QO1d49i-YZ',
        'metadata': '1GUzxXIAUrCbWA9kpaLVpwugZyb2OTxVs',
    },
    '3830': {
        'rosters': '1bKj2WnWWurW6QaWX7jxiCJm67lhfCPCd',
        'tracking': '1eOGBtHM4-8AAKBpCgZPQU32wL6CCihwb',
        'event': '1AnDFbBrS2WG8S_SlvBJ9kzkfH50KKKo7',
        'metadata': '1Ty5WXcf2kA1eICEbn4-0Vjq4ZOLyyjIr',
    },
    '3831': {
        'rosters': '17yWIYqbvZlOX78zXWIiytlA4oZmb1RcH',
        'tracking': '1olTwDbe7HiTPFdawtuemlEkr7aI06i9q',
        'event': '1wpZG5JuiwskHflbuNYWdazPuXraxqNp6',
        'metadata': '1QCOWi4c4mnopfePDwOd23TyWNWCrz5gE',
    },
    '3832': {
        'rosters': '1XrZp_Hxu6dkb-zuluYO5nnFdDywGK51B',
        'tracking': '1vq5LcPYkB9vzGEPcPdy5cC_3z_j_3IbR',
        'event': '1TqC8aF0vmKhaVD_dRosSRep-pPeJfqZc',
        'metadata': '16NS0yR_lFmlup70f8tH-8MAT7CAetXmg',
    },
    '3833': {
        'rosters': '1uaW4KTOiMBb1ygw0vuAKsrRTJ0q4s26y',
        'tracking': '1uyLCWc_aYBpdY9gkY_mD8Efp5IRf0Bxb',
        'event': '1R0Dvbmr6V1mNwY95bIlKr9eEoeD1kSGq',
        'metadata': '1w51YWrOUT6mU6W4sqGY_H0w_70TFRvCx',
    },
    '3834': {
        'rosters': '1_fNZiy78Xo4IFGU3qZuF0Txg8YExKPYr',
        'tracking': '1JggayMcLZhtWJ3WGLMAtt2z4Y5S-kAVy',
        'event': '1ZkdaKqSWqZOj-qiSh2FW4CTa5aCUGyc1',
        'metadata': '1hnpVhg54G-uI9nizifMOFXrTz1khHq2E',
    },
    '3835': {
        'rosters': '1zKTfVhk6Pv9Az-iibVR4Y4oShbB_aWw5',
        'tracking': '1JWZCdqSPq8Nvy6IOXpoQRBSvjmuLSP5t',
        'event': '140Xb2fJwlo7aarOk1lYQoOTg4W5ZLNl8',
        'metadata': '1v4-QUt6UEuvixuDkdFqj1Nbamr6WKuGe',
    },
    '3836': {
        'rosters': '175P0IZVfuJNGbKZwNnwrBRtfke5OP_Ri',
        'tracking': '1iUuZQVdJ4B6GXHInOasSToZvMVa46HJH',
        'event': '1ZflpXhkqDgSYulXKtlqiVnJfMK8HV_ia',
        'metadata': '1MFbaW2IdVMovRzoPHAcGV5Uuap55la0s',
    },
    '3837': {
        'rosters': '194Z4xdB4wrpxUdIgJq5vKNtVHetmzB9H',
        'tracking': '1hgecHGpAgMTtbfiZoEJdj2zP8vCoBTNT',
        'event': '1f357ijnsjsFxUp0cSHd8F-CKdEPo2Oof',
        'metadata': '1BwLsVcXdWsG3F0c0mxlMk3FlkSuqKszX',
    },
    '3838': {
        'rosters': '1JHuYCmOfUTVc_fxT_nmzBUBQK0Ikmm98',
        'tracking': '1SNp3eoa0OEmQ9tTKdadwWjj6OkqcRCap',
        'event': '1ZAmuVvcCYFLl9i48t2QKtcLGaftQSzzC',
        'metadata': '1SXvwt1axxPVfE0ouL_a5p8Kq6k2RuS15',
    },
    '3839': {
        'rosters': '1-1W6NGPoUzB7puMW4W_Xz8fjxlOarDAL',
        'tracking': '1Tc4B-Fkgdw5eBRchxNpLhWUytOFIerDj',
        'event': '1mv745_W-FHrSg7UP-OVtlg8uE5xHYkTr',
        'metadata': '1gDwsSohrxvNPWYWUL1Kh0KfRfH3PQ4RS',
    },
    '3840': {
        'rosters': '14q5D2Y9eMbemF3acn0grdQBxn6qO9-el',
        'tracking': '1bCiIEm1mY9A_Er2Qgh2ACOtRQwMmzo2Y',
        'event': '1xEIGq0EQdIBIBQHZ3OMmZbc1faqglqDX',
        'metadata': '1dUPhpJKdT_4QrKjGJ3xHLI04yIE5ey90',
    },
    '3841': {
        'rosters': '1n1jop4eOCAq5BY9c6HhI44n32aO3tAiT',
        'tracking': '1BrwRxy0mpbUfMmSb_rf3NebMUktA-sx3',
        'event': '1QxDt064M3qVfSPLNSIuq_tfgKPzGvMW8',
        'metadata': '1FDXCgR57mhuI3mWiitZGHnLVq-kihCSq',
    },
    '3842': {
        'rosters': '1fWTSuj-D0Ddr_ahNBsjt99fFF7oXoqrc',
        'tracking': '1N6HgYlM7iu5zuF6-swslYczcQEObaqk9',
        'event': '1Ni-4bIW7iOLZfIXKM88sDG1lV3FvNrkw',
        'metadata': '1QmRTh2LzCwIsJ-zRnE7vrTN2b-JS2Ubz',
    },
    '3843': {
        'rosters': '1f8GJ5mFhFv435-OUsBt2a3CloNi97KHx',
        'tracking': '1JoCSSBlb_pYJm459IuzDi_xQvGzWdKKm',
        'event': '14En4NRsj3Sbl_-wqTRJDcVmqiw8r-eMQ',
        'metadata': '1kA178F9E0-2R85skVWd60cuclgOLONA_',
    },
    '3844': {
        'rosters': '16yi4XriCL4hl4pgnpma3RtD33WyLD4xS',
        'tracking': '1ziBem8mk5DfJXIpQxQv29kYP56wQKy8n',
        'event': '1LwB_v9HZNRloTuTeSoYV4teeoTJ1QPwY',
        'metadata': '1q6TnpKj0BkcCNchKrsjNWBDoEV-3WOzJ',
    },
    '3845': {
        'rosters': '1ioB5rXH646epMapb43HHQumXqhfbXd_v',
        'tracking': '1XcWVaevHxqMP5vhnkKQseP6arnha34rn',
        'event': '1VvPPd4SuR60_KYa3ku3lpcYLAJKtZWiO',
        'metadata': '10YVIMkglOoZIiOwQ4LZw55jTt9u5IrRr',
    },
    '3846': {
        'rosters': '1x2MKDsVesUMqfb7cp9Pdw2SC2ICptycz',
        'tracking': '1wm4K8l6QcVaasnKnjDWCOvrlk7l-iVyK',
        'event': '1MmRhnR_Dq3bAzSECOmOAoMXeYUzqRkbc',
        'metadata': '1GXNoVxPGx9R-Akd4HTWlVtjffhQH6g-P',
    },
    '3847': {
        'rosters': '1fRsUQIw5BE4rD0ZTb9r99BlQ_nxfHMWN',
        'tracking': '1AvoYm7jlkuAWSb7wUdJGDSjohtRx9x6Y',
        'event': '1lraNCvWYqTfU7wiZ284iHOWOZee5HOoB',
        'metadata': '1bL6FPsOtET4WtpEAQxBuywh_qN30z6jF',
    },
    '3848': {
        'rosters': '16oTGO_nVrMiDPJniqMAP7igQ9eN64TM4',
        'tracking': '1o115mNUDfXj79Z0xi3J71mMeyJ-kANMj',
        'event': '19_ZlT55RVB2os_JNqprJJxBMQW0sE4Bs',
        'metadata': '1XYbJ99VezpizJiHkfMPGsEMW5y2kL_2N',
    },
    '3849': {
        'rosters': '1pGF760PRSdFi8eb2cHPtAw7Tphr7HhDY',
        'tracking': '1p6fJAK6Org8PFv1mC1g4dgwZ2jiJTKDt',
        'event': '1_XDu72doGqAXQrHrjSy-Z52C8bMLweTO',
        'metadata': '1chNFGLeRjWv9CSULNjA49pU1tqFtJw6v',
    },
    '3850': {
        'rosters': '1TmoBFxYWUQR96q6YXT2gZIYePfjz7nEt',
        'tracking': '1JOlZW03SIyXJQevXLalVhoEkhbqIcaKQ',
        'event': '1xpdV6wFe03P5-ldTjKTfzLQZsCVfbUME',
        'metadata': '1T6xJz7CC6cvndrCzc4leXpiko8sQ0z8Y',
    },
    '3851': {
        'rosters': '1vQU_o_ivjwJ3hcSMLxzeoz8TtwATuAQu',
        'tracking': '1CT8xi9MzCcZCrbEFnoHq-GJbY3fa_3ZW',
        'event': '1EJthDVPBQsZEzbqUH3nOYFpejVnPuaTi',
        'metadata': '15vKHzi8vhssyTuxS-FGgMbyDi20JCV1q',
    },
    '3852': {
        'rosters': '12Ive5s_53UeSZFGwMyj90_R6WAgLtFFY',
        'tracking': '16qUd19JfreloCpHmZndg6euERvfX7oUx',
        'event': '1kyFl-6nmpb2vZkiO2SZcNhfkNy4KjdRN',
        'metadata': '1uXbCbFTJJq2c1YEyPkmEtfUTDFr5D2ol',
    },
    '3853': {
        'rosters': '1e5pApHrr6fY5mmQpAPH94wobd-Jt7h2l',
        'tracking': '1oF4E5Vak1or1abDpsbpmEs99Qkgu-17N',
        'event': '1I_9v6f_o61QhwKA_0iSXn6FD7w-HS708',
        'metadata': '1bXTJwLXWX7mLZ6rKhbx87HodabrJ3JRt',
    },
    '3854': {
        'rosters': '149hjHGjZh1pZnr1TJAVrSaYoWCHBWe79',
        'tracking': '11jzsqheqV00ClFkoLKwQHJJnG_EaHG3a',
        'event': '1Un7fRlO9J_Oy-TDrW2emMa3en3svHjlY',
        'metadata': '1O-sGDKd8_g1HWHJM3Hqpn4jzw7EMnZhC',
    },
    '3855': {
        'rosters': '1V9LZae8LffAgJoPsFfSiGgAZ-ECipjwK',
        'tracking': '1tnxYVtXrIESTlgTq8155BCzHlygHGIVS',
        'event': '1QeD9lhjXu0Xdm6cRPQSnM-tM1r_xOWxa',
        'metadata': '1-J-Nd7tA2jvQMJmxdLcnF9QoWHFsgJkE',
    },
    '3856': {
        'rosters': '1xayiU5RLIZYliLILYPINS5PyEyrAe7iJ',
        'tracking': '1FG9D6DWKlPu-S157G-mLoJgJ76bAu4Bz',
        'event': '1Td9hvLoZHLWSBMitpAvEOTqEZmEYBLZY',
        'metadata': '1qGcskAsleHVWRS2Z82V2z16xx5_EXK0n',
    },
    '3857': {
        'rosters': '1cKygKfjmM6ryiiZCxnacQFacvuD1MWbv',
        'tracking': '1UwuVYtQNvnUT5-eTDpF7-WanggQPYwY-',
        'event': '1619eIhcsYKkXTkAxUUJpo4UEyBnzCSKh',
        'metadata': '1GOUsQIE78-oBcs0mD-8VfYenwMG7zd-K',
    },
    '3858': {
        'rosters': '10In4m0m0wCQPbUqbh8EysXgHpp9nYvvr',
        'tracking': '1w34ldL-eLFUJzo0tSBFuneDBMuSiYiK1',
        'event': '1GJT3960Xe77sM7aD9-Vh9I2nmM6mMY2U',
        'metadata': '1k9Y_LZAkef0psLOB9IskaiY-NnQmpK6W',
    },
    '3859': {
        'rosters': '1Dqwp4hxQNYBuO-7B3gxgx2BXq9Yb00rj',
        'tracking': '1gek9NwcYfp2U-RYeN__aaXgxGvvfI2_-',
        'event': '1lbbni_qaTQQYljZuxw36cgU6om-2yv1y',
        'metadata': '1Z11ZsUiPkNR8UtiL4k7vbIlOnJb_SB6O',
    },
    '10502': {
        'rosters': '1lUpYHS1bNS4jjZnFBpc06Tx6RXG0IBNO',
        'tracking': '1CsMUWAAiWmiA4N7VYZ6UfJ7n5_Zth0si',
        'event': '1X3X5koFQ6CC_xjGvVDdh0byYoPc5_EpQ',
        'metadata': '1HJysGSl1oJc5f_tRlpmkoHodtKan-m4M',
    },
    '10503': {
        'rosters': '1Z-5oJ6nWijuBOhUUaOEhH9skbtKXvZOD',
        'tracking': '1-SLhHTR1d4m5NjZNG60hdYVFU54Pu1jD',
        'event': '1Mo5FCfUC1FHURFXltYI7sPYAVsv0-1wy',
        'metadata': '1K1KHxjjqwyilGBtTOzlLhZN5BMsrWvgP',
    },
    '10504': {
        'rosters': '1VtNXanQ3XYjsiHEn1_zuvbrrI5WS6mLk',
        'tracking': '1CZENmWXqU_fttgXDIoBXED8XqLBJk6cu',
        'event': '1nMbb1RbbXX_Spbs3ZLb2xEEtn-8x6C-g',
        'metadata': '1hTd9Jrecy4mJV51YPHJTMJ2LPatiz64c',
    },
    '10505': {
        'rosters': '16UOBFPGreadc9Ay6YBHe_rYtso-1PE0x',
        'tracking': '1RhNAsNTPRa59sbp1E0GYY3MFqLhfu7aq',
        'event': '1v6kUxkd1VkTGm4qzPndyenyxHySNf31Y',
        'metadata': '1uLsR0mTZO7ZG3itERW-Eq3WDPQp7jPeW',
    },
    '10506': {
        'rosters': '1cZBdhRJySDkE_YPWvB-uNuY_ZAmBOA8-',
        'tracking': '1mBKFSXCksODBpTgakXN_VQKCUKOH4mBw',
        'event': '1SiJoAIcLFod8wB_p_--2b_IHeb8-RwGB',
        'metadata': '1-IMOz-NJ17N0d0cqNaNb5IY38CpcHTiG',
    },
    '10507': {
        'rosters': '1mjm50gm4UFrpTOL7p-6uyBnuOt-ADTG2',
        'tracking': '1T0dx4YvpkycARke_Nv0JtfOhue4u50Cn',
        'event': '12uZB1OxK0kkjCqKpeikvqz-sh46OTGpf',
        'metadata': '1PhzVr4cGZ3P6-XQFqomh709mSMlvGY4i',
    },
    '10508': {
        'rosters': '1CRZwCVtXiiSvyYUT77QqW9g31guW_liK',
        'tracking': '1GtxCEI3m09RqKg86_v-3ydMozfumgaGO',
        'event': '1VKznGh7kv3ON2kKWct9BcllW8oiLzeeC',
        'metadata': '1Sk-6jDmn37Q1aOfWK1U9fH1qfXrUywqe',
    },
    '10509': {
        'rosters': '1wqDFUNT-0gcxwOPYL-F1JOgmthDIZZr1',
        'tracking': '1pibrzrQVV73ia9n7aXMEMm1LrRS6v62J',
        'event': '161uVSwWWmOfh4kq3681pJ_DVV_amUNHH',
        'metadata': '1yyPT-OLMpH0hvQRCvzhKmFapA1YQ6YXd',
    },
    '10510': {
        'rosters': '1iB8nP1BOl3Xhx00PpABygH5C5jkozSQL',
        'tracking': '1JRA4_cZtKDVIFObR5xcIS4Xd1TbCxIv3',
        'event': '1tNKlgD4JkLHXOiycAeEdHLKM3av1yVtk',
        'metadata': '1k7PSGpRn30m19SL2XzEbmdE61QvtBTV_',
    },
    '10511': {
        'rosters': '1ubB71pZVtbP2LhHgDrbogsvdwur81Pw-',
        'tracking': '11uooPdjAPFpb7AlMHher22NnPjrJt2xX',
        'event': '1TN5ADGtZpXHYU-aV5ZJ_uEak5YWwZq0t',
        'metadata': '1pkl4RkVS2WRdTBSDJTV1V8CIu0Uelygi',
    },
    '10512': {
        'rosters': '1pBAJRzK1lfj7dD5LKTo_BxHz8fJB-3N3',
        'tracking': '10-vVPArAJtpMuYOa2zJUWjjPBcMVSsac',
        'event': '1O5gwexB5evMYeId4Q_s6K-DdjntzBtRw',
        'metadata': '1j2POWEp1eDYiSzgp4u8o7HF7gp4ATbGd',
    },
    '10513': {
        'rosters': '1klHPTRqfNDYClEIAcLWZ5CjVGJ3IRSKE',
        'tracking': '1SR0kNWjg75VuCFgVgdvCmcm941Wap3PH',
        'event': '1x_ZfUQFad7qyodb79VbFpoJaJlMwcqyz',
        'metadata': '1lO6hi9wKyH5oq1XOM2upbowuDHfJrRe5',
    },
    '10514': {
        'rosters': '15robyO-dKO3l_1ODNHvdXOPFCqpgFXlt',
        'tracking': '1g6Rvk_HbF0gj_XHdl0v4DO0qzhU93mUV',
        'event': '1VOPP3KQ2sTbI5BrrltYeyMr0Fe1FY4s6',
        'metadata': '176d8OapsetvHCwccT1195VYvul6uQxJ-',
    },
    '10515': {
        'rosters': '1-qN49cLkzEcyVF7jODAcQGbUSXKmubJB',
        'tracking': '1u_xonDBIcHQaDcRc-vntQzSsCwvqoSUJ',
        'event': '1_8QujKfOPvjeHqrOg5yxhj4R82Zifkyp',
        'metadata': '1smDKRdsT-yitpxhep7pCvSs-MoAq-1pu',
    },
    '10516': {
        'rosters': '1M3guc4Y2NBDw6hGMCflLFZqdk1JSCXwo',
        'tracking': '10DoFkFWjIDJaK6mo56SqcV925l7opBSP',
        'event': '1mUBfZROt4TVwAGsmZ6IzS4ADd9yvz7KF',
        'metadata': '1Gp-AkGYBXJijyY-fWsrV4ZBP3xq-rheE',
    },
    '10517': {
        'rosters': '1nJcElKpNPp_Tl2TNaOhvdCh5E98T2YtR',
        'tracking': '1punYKj2mY1HtewOJ5V1EFO7gHn0jaQm0',
        'event': '1RyijKWresrQuFQ8Ms56kZTvY_FTL4IcS',
        'metadata': '1Xfvmdv7XiZAUumPbjGqYfrUVAhX-0Dl3',
    },
}
